@@ -1,5 +1,5 @@
 // Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-// SPDX-License-Identifier: Apache-2.0
+// SPDX-License-Identifier: BSD-3-Clause
 
 //! Safe wrappers over the
 //! [`epoll`](http://man7.org/linux/man-pages/man7/epoll.7.html) API.
@@ -8,7 +8,7 @@ use std::io;
 use std::ops::{Deref, Drop};
 use std::os::unix::io::{AsRawFd, RawFd};
 
-#[cfg(target_os = "linux")]
+#[cfg(any(target_os = "linux", target_os = "android"))]
 use bitflags::bitflags;
 use libc::{
     epoll_create1, epoll_ctl, epoll_event, epoll_wait, EPOLLERR, EPOLLET, EPOLLEXCLUSIVE, EPOLLHUP,
@@ -19,6 +19,7 @@ use libc::{
 use crate::syscall::SyscallReturnCode;
 
 /// Wrapper over `EPOLL_CTL_*` operations that can be performed on a file descriptor.
+#[derive(Debug)]
 #[repr(i32)]
 pub enum ControlOperation {
     /// Add a file descriptor to the interest list.
@@ -204,8 +205,11 @@ pub struct Epoll {
 impl Epoll {
     /// Create a new epoll file descriptor.
     pub fn new() -> io::Result<Self> {
-        // Safe because the return code is transformed by `into_result` in a `Result`.
-        let epoll_fd = SyscallReturnCode(unsafe { epoll_create1(EPOLL_CLOEXEC) }).into_result()?;
+        let epoll_fd = SyscallReturnCode(
+            // SAFETY: Safe because the return code is transformed by `into_result` in a `Result`.
+            unsafe { epoll_create1(EPOLL_CLOEXEC) },
+        )
+        .into_result()?;
         Ok(Epoll { epoll_fd })
     }
 
@@ -247,16 +251,18 @@ impl Epoll {
     ///     .unwrap();
     /// ```
     pub fn ctl(&self, operation: ControlOperation, fd: RawFd, event: EpollEvent) -> io::Result<()> {
-        // Safe because we give a valid epoll file descriptor, a valid file descriptor to watch,
-        // as well as a valid epoll_event structure. We also check the return value.
-        SyscallReturnCode(unsafe {
-            epoll_ctl(
-                self.epoll_fd,
-                operation as i32,
-                fd,
-                &event as *const EpollEvent as *mut epoll_event,
-            )
-        })
+        SyscallReturnCode(
+            // SAFETY: Safe because we give a valid epoll file descriptor, a valid file descriptor
+            // to watch, as well as a valid epoll_event structure. We also check the return value.
+            unsafe {
+                epoll_ctl(
+                    self.epoll_fd,
+                    operation as i32,
+                    fd,
+                    &event as *const EpollEvent as *mut epoll_event,
+                )
+            },
+        )
         .into_empty_result()
     }
 
@@ -295,17 +301,20 @@ impl Epoll {
     /// assert_eq!(ev_count, 1);
     /// ```
     pub fn wait(&self, timeout: i32, events: &mut [EpollEvent]) -> io::Result<usize> {
-        // Safe because we give a valid epoll file descriptor and an array of epoll_event structures
-        // that will be modified by the kernel to indicate information about the subset of file
-        // descriptors in the interest list. We also check the return value.
-        let events_count = SyscallReturnCode(unsafe {
-            epoll_wait(
-                self.epoll_fd,
-                events.as_mut_ptr() as *mut epoll_event,
-                events.len() as i32,
-                timeout,
-            )
-        })
+        let events_count = SyscallReturnCode(
+            // SAFETY: Safe because we give a valid epoll file descriptor and an array of
+            // epoll_event structures that will be modified by the kernel to indicate information
+            // about the subset of file descriptors in the interest list.
+            // We also check the return value.
+            unsafe {
+                epoll_wait(
+                    self.epoll_fd,
+                    events.as_mut_ptr() as *mut epoll_event,
+                    events.len() as i32,
+                    timeout,
+                )
+            },
+        )
         .into_result()? as usize;
 
         Ok(events_count)
@@ -320,7 +329,7 @@ impl AsRawFd for Epoll {
 
 impl Drop for Epoll {
     fn drop(&mut self) {
-        // Safe because this fd is opened with `epoll_create` and we trust
+        // SAFETY: Safe because this fd is opened with `epoll_create` and we trust
         // the kernel to give us a valid fd.
         unsafe {
             libc::close(self.epoll_fd);
@@ -377,20 +386,12 @@ mod tests {
         // For EPOLL_CTL_ADD behavior we will try to add some fds with different event masks into
         // the interest list of epoll instance.
         assert!(epoll
-            .ctl(
-                ControlOperation::Add,
-                event_fd_1.as_raw_fd() as i32,
-                event_1
-            )
+            .ctl(ControlOperation::Add, event_fd_1.as_raw_fd(), event_1)
             .is_ok());
 
         // We can't add twice the same fd to epoll interest list.
         assert!(epoll
-            .ctl(
-                ControlOperation::Add,
-                event_fd_1.as_raw_fd() as i32,
-                event_1
-            )
+            .ctl(ControlOperation::Add, event_fd_1.as_raw_fd(), event_1)
             .is_err());
 
         let event_fd_2 = EventFd::new(libc::EFD_NONBLOCK).unwrap();
@@ -398,7 +399,7 @@ mod tests {
         assert!(epoll
             .ctl(
                 ControlOperation::Add,
-                event_fd_2.as_raw_fd() as i32,
+                event_fd_2.as_raw_fd(),
                 // For this fd, we want an Event instance that has `data` field set to other
                 // value than the value of the fd and `events` without EPOLLIN type set.
                 EpollEvent::new(EventSet::OUT, 10)
@@ -411,11 +412,7 @@ mod tests {
         let event_fd_3 = EventFd::new(libc::EFD_NONBLOCK).unwrap();
         let event_3 = EpollEvent::new(EventSet::OUT | EventSet::IN, event_fd_3.as_raw_fd() as u64);
         assert!(epoll
-            .ctl(
-                ControlOperation::Add,
-                event_fd_3.as_raw_fd() as i32,
-                event_3
-            )
+            .ctl(ControlOperation::Add, event_fd_3.as_raw_fd(), event_3)
             .is_ok());
 
         // Let's check `epoll_wait()` behavior for our epoll instance.
@@ -449,11 +446,7 @@ mod tests {
         // that we want to monitor this time on event_fd_1.
         event_1 = EpollEvent::new(EventSet::OUT, 20);
         assert!(epoll
-            .ctl(
-                ControlOperation::Modify,
-                event_fd_1.as_raw_fd() as i32,
-                event_1
-            )
+            .ctl(ControlOperation::Modify, event_fd_1.as_raw_fd(), event_1)
             .is_ok());
 
         let event_fd_4 = EventFd::new(libc::EFD_NONBLOCK).unwrap();
@@ -461,7 +454,7 @@ mod tests {
         assert!(epoll
             .ctl(
                 ControlOperation::Modify,
-                event_fd_4.as_raw_fd() as i32,
+                event_fd_4.as_raw_fd(),
                 EpollEvent::default()
             )
             .is_err());
@@ -477,7 +470,7 @@ mod tests {
         assert!(epoll
             .ctl(
                 ControlOperation::Modify,
-                event_fd_1.as_raw_fd() as i32,
+                event_fd_1.as_raw_fd(),
                 EpollEvent::default()
             )
             .is_ok());
@@ -490,7 +483,7 @@ mod tests {
         assert!(epoll
             .ctl(
                 ControlOperation::Delete,
-                event_fd_2.as_raw_fd() as i32,
+                event_fd_2.as_raw_fd(),
                 EpollEvent::default()
             )
             .is_ok());
@@ -506,7 +499,7 @@ mod tests {
         assert!(epoll
             .ctl(
                 ControlOperation::Delete,
-                event_fd_4.as_raw_fd() as i32,
+                event_fd_4.as_raw_fd(),
                 EpollEvent::default()
             )
             .is_err());
